@@ -1,14 +1,15 @@
 # Setting up logging here because this is the root of the module
 import logging
 
-__all__ = ['client', 'user_auth', 'aws_auth', 'util']
+__all__ = ['aws_auth', 'client', 'network_util', 'url_util', 'user_auth']
+
+CLIENT_VERSION = '2.5.2'
 
-CLIENT_VERSION = '2.5.0'
 
 class CerberusClientException(Exception):
     """Wrap third-party exceptions expected by the Cerberus client."""
     pass
 
+
 # This avoids the "No handler found" warnings.
 logging.getLogger(__name__).addHandler(logging.NullHandler())
-
